@@ -2,10 +2,9 @@
 
 import os
 import argparse
-from commands import available_commands
+from auterioncli.commands import available_commands
 
-from meta_util import PersistentState, check_for_updates
-from commands.utils import Device
+from auterioncli.meta_util import PersistentState, check_for_updates
 
 
 def main():
